@@ -28,20 +28,21 @@ for my $event_id ( 1039 .. 1460 ) {
     my %data = ( white => 0, blue => 0 );
 
     for ( @{$contests} ) {
-    $annual_data{$event->{year}}{contests}++;
-    $annual_data{$event->{year}}{penalties} += $_->{penalty_w} + $_->{penalty_b};
+        $annual_data{ $event->{year} }{contests}++;
+        $annual_data{ $event->{year} }{penalties}
+            += $_->{penalty_w} + $_->{penalty_b};
         $data{white} += $_->{penalty_w} if $_->{penalty_w};
         $data{blue}  += $_->{penalty_b} if $_->{penalty_b};
     }
 
     say join ',', $event->{title} // '',
-        $event->{year} // '',
+        $event->{year}    // '',
         $event->{country} // '',
-    $data{white},
-    $data{blue};
+        $data{white},
+        $data{blue};
 }
 
-$Data::Dumper::Sortkeys=1;
+$Data::Dumper::Sortkeys = 1;
 say Dumper \%annual_data;
 
 1;
